@@ -2,7 +2,7 @@
 import inspect
 
 import rope.base.evaluate
-from rope.base import pynames, pyobjects, arguments, utils
+from rope.base import pynames, pyobjects, arguments, utils, ast
 
 
 class BuiltinModule(pyobjects.AbstractModule):
@@ -110,6 +110,9 @@ class BuiltinUnknown(_BuiltinElement, pyobjects.PyObject):
         self.builtin = builtin
         self.type = pyobjects.get_unknown()
 
+    def get_name(self):
+        return getattr(type(self.builtin), '__name__', None)
+
     @utils.saveit
     def get_attributes(self):
         return _object_attributes(self.builtin, self)
@@ -120,7 +123,12 @@ def _object_attributes(obj, parent):
     for name in dir(obj):
         if name == 'None':
             continue
-        child = getattr(obj, name)
+        try:
+            child = getattr(obj, name)
+        except AttributeError:
+            # descriptors are allowed to raise AttributeError
+            # even if they are in dir()
+            continue
         pyobject = None
         if inspect.isclass(child):
             pyobject = BuiltinClass(child, {}, parent=parent)
@@ -141,8 +149,10 @@ def _create_builtin_type_getter(cls):
         return cls._generated[args]
     return _get_builtin
 
+
 def _create_builtin_getter(cls):
     type_getter = _create_builtin_type_getter(cls)
+
     def _get_builtin(*args):
         return pyobjects.PyObject(type_getter(*args))
     return _get_builtin
@@ -225,7 +235,7 @@ class _AttributeCollector(object):
         except AttributeError:
             if check_existence:
                 raise
-            builtin=None
+            builtin = None
         self.attributes[name] = BuiltinName(
             BuiltinFunction(returned=returned, function=function,
                             argnames=argnames, builtin=builtin))
@@ -244,7 +254,8 @@ class List(BuiltinClass):
         collector('__new__', function=self._new_list)
 
         # Adding methods
-        collector('append', function=self._list_add, argnames=['self', 'value'])
+        collector('append', function=self._list_add,
+                  argnames=['self', 'value'])
         collector('__setitem__', function=self._list_add,
                   argnames=['self', 'index', 'value'])
         collector('insert', function=self._list_add,
@@ -298,7 +309,6 @@ class Dict(BuiltinClass):
     def __init__(self, keys=None, values=None):
         self.keys = keys
         self.values = values
-        item = get_tuple(self.keys, self.values)
         collector = _AttributeCollector(dict)
         collector('__new__', function=self._new_dict)
         collector('__setitem__', function=self._dict_add)
@@ -319,7 +329,8 @@ class Dict(BuiltinClass):
             if holding is None:
                 return get_dict()
             type = holding.get_type()
-            if isinstance(type, Tuple) and len(type.get_holding_objects()) == 2:
+            if isinstance(type, Tuple) and \
+                    len(type.get_holding_objects()) == 2:
                 return get_dict(*type.get_holding_objects())
         return _create_builtin(args, do_create)
 
@@ -376,7 +387,7 @@ class Dict(BuiltinClass):
         if new_dict and isinstance(new_dict.get_object().get_type(), Dict):
             args = arguments.ObjectArguments([new_dict])
             items = new_dict.get_object()['popitem'].\
-                    get_object().get_returned_object(args)
+                get_object().get_returned_object(args)
             context.save_per_name(items)
         else:
             holding = _infer_sequence_for_pyname(new_dict)
@@ -397,7 +408,8 @@ class Tuple(BuiltinClass):
             first = objects[0]
         attributes = {
             '__getitem__': BuiltinName(BuiltinFunction(first)),
-            '__getslice__': BuiltinName(BuiltinFunction(pyobjects.PyObject(self))),
+            '__getslice__':
+            BuiltinName(BuiltinFunction(pyobjects.PyObject(self))),
             '__new__': BuiltinName(BuiltinFunction(function=self._new_tuple)),
             '__iter__': BuiltinName(BuiltinFunction(get_iterator(first)))}
         super(Tuple, self).__init__(tuple, attributes)
@@ -477,8 +489,9 @@ class Str(BuiltinClass):
 
         self_methods = ['__getitem__', '__getslice__', 'capitalize', 'center',
                         'decode', 'encode', 'expandtabs', 'join', 'ljust',
-                        'lower', 'lstrip', 'replace', 'rjust', 'rstrip', 'strip',
-                        'swapcase', 'title', 'translate', 'upper', 'zfill']
+                        'lower', 'lstrip', 'replace', 'rjust', 'rstrip',
+                        'strip', 'swapcase', 'title', 'translate', 'upper',
+                        'zfill']
         for method in self_methods:
             collector(method, self_object)
 
@@ -506,6 +519,7 @@ class BuiltinName(pynames.PyName):
     def get_definition_location(self):
         return (None, None)
 
+
 class Iterator(pyobjects.AbstractClass):
 
     def __init__(self, holding=None):
@@ -531,7 +545,8 @@ class Generator(pyobjects.AbstractClass):
         self.holding = holding
         self.attributes = {
             'next': BuiltinName(BuiltinFunction(self.holding)),
-            '__iter__': BuiltinName(BuiltinFunction(get_iterator(self.holding))),
+            '__iter__': BuiltinName(BuiltinFunction(
+                get_iterator(self.holding))),
             'close': BuiltinName(BuiltinFunction()),
             'send': BuiltinName(BuiltinFunction()),
             'throw': BuiltinName(BuiltinFunction())}
@@ -548,10 +563,10 @@ get_generator = _create_builtin_getter(Generator)
 class File(BuiltinClass):
 
     def __init__(self):
-        self_object = pyobjects.PyObject(self)
         str_object = get_str()
         str_list = get_list(get_str())
         attributes = {}
+
         def add(name, returned=None, function=None):
             builtin = getattr(file, name, None)
             attributes[name] = BuiltinName(
@@ -579,7 +594,8 @@ class Property(BuiltinClass):
             'fget': BuiltinName(BuiltinFunction()),
             'fset': BuiltinName(pynames.UnboundName()),
             'fdel': BuiltinName(pynames.UnboundName()),
-            '__new__': BuiltinName(BuiltinFunction(function=_property_function))}
+            '__new__': BuiltinName(
+                BuiltinFunction(function=_property_function))}
         super(Property, self).__init__(property, attributes)
 
     def get_property_object(self, args):
@@ -597,6 +613,7 @@ class Lambda(pyobjects.AbstractFunction):
     def __init__(self, node, scope):
         super(Lambda, self).__init__()
         self.node = node
+        self.arguments = node.args
         self.scope = scope
 
     def get_returned_object(self, args):
@@ -606,9 +623,37 @@ class Lambda(pyobjects.AbstractFunction):
         else:
             return pyobjects.get_unknown()
 
-    def get_pattributes(self):
+    def get_module(self):
+        return self.parent.get_module()
+
+    def get_scope(self):
+        return self.scope
+
+    def get_kind(self):
+        return 'lambda'
+
+    def get_ast(self):
+        return self.node
+
+    def get_attributes(self):
         return {}
 
+    def get_name(self):
+        return 'lambda'
+
+    def get_param_names(self, special_args=True):
+        result = [node.id for node in self.arguments.args
+                  if isinstance(node, ast.Name)]
+        if self.arguments.vararg:
+            result.append('*' + self.arguments.vararg)
+        if self.arguments.kwarg:
+            result.append('**' + self.arguments.kwarg)
+        return result
+
+    @property
+    def parent(self):
+        return self.scope.pyobject
+
 
 class BuiltinObject(BuiltinClass):
 
@@ -628,11 +673,13 @@ def _infer_sequence_for_pyname(pyname):
     seq = pyname.get_object()
     args = arguments.ObjectArguments([pyname])
     if '__iter__' in seq:
-        iter = seq['__iter__'].get_object().\
-               get_returned_object(args)
+        obj = seq['__iter__'].get_object()
+        if not isinstance(obj, pyobjects.AbstractFunction):
+            return None
+        iter = obj.get_returned_object(args)
         if iter is not None and 'next' in iter:
             holding = iter['next'].get_object().\
-                      get_returned_object(args)
+                get_returned_object(args)
             return holding
 
 
@@ -651,12 +698,15 @@ def _create_builtin(args, creator):
 def _range_function(args):
     return get_list()
 
+
 def _reversed_function(args):
     return _create_builtin(args, get_iterator)
 
+
 def _sorted_function(args):
     return _create_builtin(args, get_list)
 
+
 def _super_function(args):
     passed_class, passed_self = args.get_arguments(['type', 'self'])
     if passed_self is None:
@@ -670,6 +720,7 @@ def _super_function(args):
                 return pyobjects.PyObject(supers[0])
         return passed_self
 
+
 def _zip_function(args):
     args = args.get_pynames(['sequence'])
     objects = []
@@ -682,6 +733,7 @@ def _zip_function(args):
     tuple = get_tuple(*objects)
     return get_list(tuple)
 
+
 def _enumerate_function(args):
     passed = args.get_pynames(['sequence'])[0]
     if passed is None:
@@ -691,6 +743,7 @@ def _enumerate_function(args):
     tuple = get_tuple(None, holding)
     return get_iterator(tuple)
 
+
 def _iter_function(args):
     passed = args.get_pynames(['sequence'])[0]
     if passed is None:
@@ -699,6 +752,7 @@ def _iter_function(args):
         holding = _infer_sequence_for_pyname(passed)
     return get_iterator(holding)
 
+
 def _input_function(args):
     return get_str()
 
@@ -712,17 +766,25 @@ _initial_builtins = {
     'file': BuiltinName(get_file_type()),
     'open': BuiltinName(get_file_type()),
     'unicode': BuiltinName(get_str_type()),
-    'range': BuiltinName(BuiltinFunction(function=_range_function, builtin=range)),
-    'reversed': BuiltinName(BuiltinFunction(function=_reversed_function, builtin=reversed)),
-    'sorted': BuiltinName(BuiltinFunction(function=_sorted_function, builtin=sorted)),
-    'super': BuiltinName(BuiltinFunction(function=_super_function, builtin=super)),
-    'property': BuiltinName(BuiltinFunction(function=_property_function, builtin=property)),
+    'range': BuiltinName(BuiltinFunction(function=_range_function,
+                         builtin=range)),
+    'reversed': BuiltinName(BuiltinFunction(function=_reversed_function,
+                            builtin=reversed)),
+    'sorted': BuiltinName(BuiltinFunction(function=_sorted_function,
+                          builtin=sorted)),
+    'super': BuiltinName(BuiltinFunction(function=_super_function,
+                         builtin=super)),
+    'property': BuiltinName(BuiltinFunction(function=_property_function,
+                            builtin=property)),
     'zip': BuiltinName(BuiltinFunction(function=_zip_function, builtin=zip)),
-    'enumerate': BuiltinName(BuiltinFunction(function=_enumerate_function, builtin=enumerate)),
+    'enumerate': BuiltinName(BuiltinFunction(function=_enumerate_function,
+                             builtin=enumerate)),
     'object': BuiltinName(BuiltinObject()),
     'type': BuiltinName(BuiltinType()),
-    'iter': BuiltinName(BuiltinFunction(function=_iter_function, builtin=iter)),
-    'raw_input': BuiltinName(BuiltinFunction(function=_input_function, builtin=raw_input)),
-    }
+    'iter': BuiltinName(BuiltinFunction(function=_iter_function,
+                        builtin=iter)),
+    'raw_input': BuiltinName(BuiltinFunction(function=_input_function,
+                             builtin=raw_input)),
+}
 
 builtins = BuiltinModule('__builtin__', initial=_initial_builtins)
