@@ -4,8 +4,8 @@ import warnings
 
 import rope.base.codeanalyze
 import rope.base.evaluate
-from rope.base import pyobjects, pyobjectsdef, pynames, builtins, exceptions, worder
-from rope.base.codeanalyze import SourceLinesAdapter
+from rope.base import (pyobjects, pyobjectsdef, pynames, builtins,
+                       exceptions, worder)
 from rope.contrib import fixsyntax
 from rope.refactor import functionutils
 
@@ -55,7 +55,6 @@ def get_doc(project, source_code, offset, resource=None, maxfixes=1):
     """Get the pydoc"""
     fixer = fixsyntax.FixSyntax(project.pycore, source_code,
                                 resource, maxfixes)
-    pymodule = fixer.get_pymodule()
     pyname = fixer.pyname_at(offset)
     if pyname is None:
         return None
@@ -90,7 +89,6 @@ def get_calltip(project, source_code, offset, resource=None,
     """
     fixer = fixsyntax.FixSyntax(project.pycore, source_code,
                                 resource, maxfixes)
-    pymodule = fixer.get_pymodule()
     pyname = fixer.pyname_at(offset)
     if pyname is None:
         return None
@@ -110,7 +108,6 @@ def get_definition_location(project, source_code, offset,
     """
     fixer = fixsyntax.FixSyntax(project.pycore, source_code,
                                 resource, maxfixes)
-    pymodule = fixer.get_pymodule()
     pyname = fixer.pyname_at(offset)
     if pyname is not None:
         module, lineno = pyname.get_definition_location()
@@ -153,12 +150,8 @@ class CompletionProposal(object):
 
     def __init__(self, name, scope, pyname=None):
         self.name = name
-        self.scope = scope
         self.pyname = pyname
-        if pyname is not None:
-            self.type = self._get_type()
-        else:
-            self.type = None
+        self.scope = self._get_scope(scope)
 
     def __str__(self):
         return '%s (%s, %s)' % (self.name, self.scope, self.type)
@@ -180,26 +173,22 @@ class CompletionProposal(object):
             if isinstance(pyobject, pyobjects.AbstractFunction):
                 return pyobject.get_param_names()
 
-    def _get_type(self):
+    @property
+    def type(self):
         pyname = self.pyname
         if isinstance(pyname, builtins.BuiltinName):
-            self.scope = 'builtin'
             pyobject = pyname.get_object()
             if isinstance(pyobject, builtins.BuiltinFunction):
                 return 'function'
             elif isinstance(pyobject, builtins.BuiltinClass):
-                clsobj = pyobject.builtin
                 return 'class'
             elif isinstance(pyobject, builtins.BuiltinObject) or \
-                 isinstance(pyobject, builtins.BuiltinName):
+                    isinstance(pyobject, builtins.BuiltinName):
                 return 'instance'
         elif isinstance(pyname, pynames.ImportedModule):
-            self.scope = 'imported'
             return 'module'
         elif isinstance(pyname, pynames.ImportedName) or \
-           isinstance(pyname, pynames.DefinedName):
-            if isinstance(pyname, pynames.ImportedName):
-                self.scope = 'imported'
+                isinstance(pyname, pynames.DefinedName):
             pyobject = pyname.get_object()
             if isinstance(pyobject, pyobjects.AbstractFunction):
                 return 'function'
@@ -207,6 +196,14 @@ class CompletionProposal(object):
                 return 'class'
         return 'instance'
 
+    def _get_scope(self, scope):
+        if isinstance(self.pyname, builtins.BuiltinName):
+            return 'builtin'
+        if isinstance(self.pyname, pynames.ImportedModule) or \
+           isinstance(self.pyname, pynames.ImportedName):
+            return 'imported'
+        return scope
+
     def get_doc(self):
         """Get the proposed object's docstring.
 
@@ -221,7 +218,7 @@ class CompletionProposal(object):
 
     @property
     def kind(self):
-        warnings.warn("the proposal's `kind` property is deprecated, " \
+        warnings.warn("the proposal's `kind` property is deprecated, "
                       "use `scope` instead")
         return self.scope
 
@@ -308,7 +305,7 @@ class _PythonCodeAssist(object):
         current_offset = offset - 1
         while current_offset >= 0 and (source_code[current_offset].isalnum() or
                                        source_code[current_offset] in '_'):
-            current_offset -= 1;
+            current_offset -= 1
         return current_offset + 1
 
     def _matching_keywords(self, starting):
@@ -338,11 +335,12 @@ class _PythonCodeAssist(object):
                 compl_scope = 'imported'
             for name, pyname in element.get_attributes().items():
                 if name.startswith(self.starting):
-                    result[name] = CompletionProposal(name, compl_scope, pyname)
+                    result[name] = CompletionProposal(name, compl_scope,
+                                                      pyname)
         return result
 
     def _undotted_completions(self, scope, result, lineno=None):
-        if scope.parent != None:
+        if scope.parent is not None:
             self._undotted_completions(scope.parent, result)
         if lineno is None:
             names = scope.get_propagated_names()
@@ -412,24 +410,21 @@ class _PythonCodeAssist(object):
         if offset == 0:
             return {}
         word_finder = worder.Worder(self.code, True)
-        lines = SourceLinesAdapter(self.code)
-        lineno = lines.get_line_number(offset)
         if word_finder.is_on_function_call_keyword(offset - 1):
-            name_finder = rope.base.evaluate.ScopeNameFinder(pymodule)
             function_parens = word_finder.\
                 find_parens_start_from_inside(offset - 1)
             primary = word_finder.get_primary_at(function_parens - 1)
             try:
                 function_pyname = rope.base.evaluate.\
                     eval_str(scope, primary)
-            except exceptions.BadIdentifierError, e:
+            except exceptions.BadIdentifierError:
                 return {}
             if function_pyname is not None:
                 pyobject = function_pyname.get_object()
                 if isinstance(pyobject, pyobjects.AbstractFunction):
                     pass
                 elif isinstance(pyobject, pyobjects.AbstractClass) and \
-                     '__init__' in pyobject:
+                        '__init__' in pyobject:
                     pyobject = pyobject['__init__'].get_object()
                 elif '__call__' in pyobject:
                     pyobject = pyobject['__call__'].get_object()
@@ -454,12 +449,12 @@ class _ProposalSorter(object):
         self.proposals = code_assist_proposals
         if scopepref is None:
             scopepref = ['parameter_keyword', 'local', 'global', 'imported',
-                        'attribute', 'builtin', 'keyword']
+                         'attribute', 'builtin', 'keyword']
         self.scopepref = scopepref
         if typepref is None:
             typepref = ['class', 'function', 'instance', 'module', None]
         self.typerank = dict((type, index)
-                              for index, type in enumerate(typepref))
+                             for index, type in enumerate(typepref))
 
     def get_sorted_proposal_list(self):
         """Return a list of `CodeAssistProposal`"""
@@ -470,7 +465,7 @@ class _ProposalSorter(object):
         for scope in self.scopepref:
             scope_proposals = proposals.get(scope, [])
             scope_proposals = [proposal for proposal in scope_proposals
-                              if proposal.type in self.typerank]
+                               if proposal.type in self.typerank]
             scope_proposals.sort(self._proposal_cmp)
             result.extend(scope_proposals)
         return result
@@ -525,7 +520,8 @@ class PyDocExtractor(object):
     def _get_class_docstring(self, pyclass):
         contents = self._trim_docstring(pyclass.get_doc(), 2)
         supers = [super.get_name() for super in pyclass.get_superclasses()]
-        doc = 'class %s(%s):\n\n' % (pyclass.get_name(), ', '.join(supers)) + contents
+        doc = 'class %s(%s):\n\n' % (pyclass.get_name(), ', '.join(supers)) \
+            + contents
 
         if '__init__' in pyclass:
             init = pyclass['__init__'].get_object()
@@ -543,7 +539,7 @@ class PyDocExtractor(object):
 
     def _is_method(self, pyfunction):
         return isinstance(pyfunction, pyobjects.PyFunction) and \
-               isinstance(pyfunction.parent, pyobjects.PyClass)
+            isinstance(pyfunction.parent, pyobjects.PyClass)
 
     def _get_single_function_docstring(self, pyfunction):
         signature = self._get_function_signature(pyfunction)
@@ -578,7 +574,6 @@ class PyDocExtractor(object):
             parent = parent.parent
         if add_module:
             if isinstance(pyobject, pyobjects.PyFunction):
-                module = pyobject.get_module()
                 location.insert(0, self._get_module(pyobject))
             if isinstance(parent, builtins.BuiltinModule):
                 location.insert(0, parent.get_name() + '.')
