@@ -12,7 +12,7 @@ from rope.refactor import (sourceutils, similarfinder,
 #
 # _ExtractInfo: holds information about the refactoring; it is passed
 # to the parts that need to have information about the refactoring
-# 
+#
 # _ExtractCollector: merely saves all of the information necessary for
 # performing the refactoring.
 #
@@ -153,8 +153,8 @@ class _ExtractInfo(object):
     @property
     def one_line(self):
         return self.region != self.lines_region and \
-               (self.logical_lines.logical_line_in(self.region_lines[0]) ==
-                self.logical_lines.logical_line_in(self.region_lines[1]))
+            (self.logical_lines.logical_line_in(self.region_lines[0]) ==
+             self.logical_lines.logical_line_in(self.region_lines[1]))
 
     @property
     def global_(self):
@@ -163,7 +163,7 @@ class _ExtractInfo(object):
     @property
     def method(self):
         return self.scope.parent is not None and \
-               self.scope.parent.get_kind() == 'Class'
+            self.scope.parent.get_kind() == 'Class'
 
     @property
     def indents(self):
@@ -182,6 +182,7 @@ class _ExtractInfo(object):
         return self.source[self.region[0]:self.region[1]]
 
     _returned = None
+
     @property
     def returned(self):
         """Does the extracted piece contain return statement"""
@@ -273,7 +274,8 @@ class _ExtractPerformer(object):
                 if self.info.variable:
                     return [self.info.scope_region]
                 else:
-                    return [self.info._get_scope_region(self.info.scope.parent)]
+                    return [self.info._get_scope_region(
+                        self.info.scope.parent)]
         else:
             return [self.info.region]
 
@@ -391,8 +393,9 @@ class _ExceptionalConditionChecker(object):
                                    'contain complete statements.')
 
     def _is_region_on_a_word(self, info):
-        if info.region[0] > 0 and self._is_on_a_word(info, info.region[0] - 1) or \
-           self._is_on_a_word(info, info.region[1] - 1):
+        if info.region[0] > 0 and \
+                self._is_on_a_word(info, info.region[0] - 1) or \
+                self._is_on_a_word(info, info.region[1] - 1):
             return True
 
     def _is_on_a_word(self, info, offset):
@@ -487,11 +490,11 @@ class _ExtractMethodParts(object):
                 args.remove(self_name)
             args.insert(0, self_name)
         return prefix + self.info.new_name + \
-               '(%s)' % self._get_comma_form(args)
+            '(%s)' % self._get_comma_form(args)
 
     def _extracting_method(self):
         return self.info.method and not self.info.make_global and \
-               _get_function_kind(self.info.scope) == 'method'
+            _get_function_kind(self.info.scope) == 'method'
 
     def _get_self_name(self):
         param_names = self.info.scope.pyobject.get_param_names()
@@ -503,7 +506,7 @@ class _ExtractMethodParts(object):
         if self.info.method and not self.info.make_global:
             if _get_function_kind(self.info.scope) == 'method':
                 self_name = self._get_self_name()
-                if  self_name in args:
+                if self_name in args:
                     args.remove(self_name)
                 prefix = self_name + '.'
             else:
@@ -540,8 +543,10 @@ class _ExtractMethodParts(object):
         if not self.info.one_line:
             result = (self.info_collector.prewritten &
                       self.info_collector.read)
-            result |= (self.info_collector.maybe_written &
-                       self.info_collector.postread)
+            result |= (self.info_collector.prewritten &
+                       self.info_collector.postread &
+                       (self.info_collector.maybe_written -
+                        self.info_collector.written))
             return list(result)
         start = self.info.region[0]
         if start == self.info.lines_region[0]:
@@ -555,7 +560,7 @@ class _ExtractMethodParts(object):
         if self.info.one_line or self.info.returned:
             return []
         written = self.info_collector.written | \
-                  self.info_collector.maybe_written
+            self.info_collector.maybe_written
         return list(written & self.info_collector.postread)
 
     def _get_unindented_function_body(self, returns):
@@ -575,7 +580,7 @@ class _ExtractVariableParts(object):
 
     def get_definition(self):
         result = self.info.new_name + ' = ' + \
-                 _join_lines(self.info.extracted) + '\n'
+            _join_lines(self.info.extracted) + '\n'
         return result
 
     def get_body_pattern(self):
@@ -669,7 +674,6 @@ class _FunctionInformationCollector(object):
         self._handle_conditional_node(node)
 
 
-
 def _get_argnames(arguments):
     result = [node.id for node in arguments.args
               if isinstance(node, ast.Name)]
@@ -768,6 +772,7 @@ class _UnmatchedBreakOrContinueFinder(object):
         ast.walk(node, visitor)
         return visitor.error
 
+
 def _get_function_kind(scope):
     return scope.pyobject.get_kind()
 
@@ -777,6 +782,7 @@ def _parse_text(body):
     node = ast.parse(body)
     return node
 
+
 def _join_lines(code):
     lines = []
     for line in code.splitlines():
