@@ -2,7 +2,7 @@ import unittest
 
 import rope.base.history
 import rope.contrib.changestack
-from rope.base.change import *
+import rope.base.change
 from ropetest import testutils
 
 
@@ -20,9 +20,9 @@ class ChangeStackTest(unittest.TestCase):
         myfile = self.project.root.create_file('myfile.txt')
         myfile.write('1')
         stack = rope.contrib.changestack.ChangeStack(self.project)
-        stack.push(ChangeContents(myfile, '2'))
+        stack.push(rope.base.change.ChangeContents(myfile, '2'))
         self.assertEquals('2', myfile.read())
-        stack.push(ChangeContents(myfile, '3'))
+        stack.push(rope.base.change.ChangeContents(myfile, '3'))
         self.assertEquals('3', myfile.read())
         stack.pop_all()
         self.assertEquals('1', myfile.read())
