@@ -1,4 +1,7 @@
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 
 from rope.base import exceptions
 from rope.refactor import move
@@ -24,13 +27,13 @@ class MoveRefactoringTest(unittest.TestCase):
 
     def _move(self, resource, offset, dest_resource):
         changes = move.create_move(self.project, resource, offset).\
-                  get_changes(dest_resource)
+            get_changes(dest_resource)
         self.project.do(changes)
 
     def test_simple_moving(self):
         self.mod1.write('class AClass(object):\n    pass\n')
         self._move(self.mod1, self.mod1.read().index('AClass') + 1,
-                              self.mod2)
+                   self.mod2)
         self.assertEquals('', self.mod1.read())
         self.assertEquals('class AClass(object):\n    pass\n',
                           self.mod2.read())
@@ -63,25 +66,27 @@ class MoveRefactoringTest(unittest.TestCase):
         self.mod2.write('from mod1 import AClass\na_var = AClass()\n')
         self._move(self.mod1, self.mod1.read().index('AClass') + 1,
                    self.mod2)
-        self.assertEquals('class AClass(object):\n    pass\na_var = AClass()\n',
+        self.assertEquals('class AClass(object):\n    '
+                          'pass\na_var = AClass()\n',
                           self.mod2.read())
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_folder_destination(self):
         folder = self.project.root.create_folder('folder')
         self.mod1.write('class AClass(object):\n    pass\n')
-        self._move(self.mod1, self.mod1.read().index('AClass') + 1, folder)
+        with self.assertRaises(exceptions.RefactoringError):
+            self._move(self.mod1, self.mod1.read().index('AClass') + 1, folder)
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_raising_exception_for_moving_non_global_elements(self):
-        self.mod1.write('def a_func():\n    class AClass(object):\n        pass\n')
-        self._move(self.mod1, self.mod1.read().index('AClass') + 1,
-                   self.mod2)
+        self.mod1.write(
+            'def a_func():\n    class AClass(object):\n        pass\n')
+        with self.assertRaises(exceptions.RefactoringError):
+            self._move(self.mod1, self.mod1.read().index('AClass') + 1,
+                       self.mod2)
 
-    @testutils.assert_raises(exceptions.RefactoringError)
-    def test_raising_exception_for_moving_global_elements_to_the_same_module(self):
+    def test_raising_exception_for_mov_glob_elemnts_to_the_same_module(self):
         self.mod1.write('def a_func():\n    pass\n')
-        self._move(self.mod1, self.mod1.read().index('a_func'), self.mod1)
+        with self.assertRaises(exceptions.RefactoringError):
+            self._move(self.mod1, self.mod1.read().index('a_func'), self.mod1)
 
     def test_moving_used_imports_to_destination_module(self):
         self.mod3.write('a_var = 10')
@@ -246,18 +251,19 @@ class MoveRefactoringTest(unittest.TestCase):
         self.assertEquals('import os\nimport mod4\n\n\n'
                           'print(mod4.a_var)\n', self.mod2.read())
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_moving_module_refactoring_and_nonexistent_destinations(self):
         self.mod4.write('a_var = 1')
         self.mod2.write('from pkg import mod4\n'
                         'import os\n\n\nprint(mod4.a_var)\n')
-        mover = move.create_move(self.project, self.mod4)
-        mover.get_changes(None).do()
+        with self.assertRaises(exceptions.RefactoringError):
+            mover = move.create_move(self.project, self.mod4)
+            mover.get_changes(None).do()
 
     def test_moving_methods_choosing_the_correct_class(self):
         code = 'class A(object):\n    def a_method(self):\n        pass\n'
         self.mod1.write(code)
-        mover = move.create_move(self.project, self.mod1, code.index('a_method'))
+        mover = move.create_move(self.project, self.mod1,
+                                 code.index('a_method'))
         self.assertTrue(isinstance(mover, move.MoveMethod))
 
     def test_moving_methods_getting_new_method_for_empty_methods(self):
@@ -291,7 +297,8 @@ class MoveRefactoringTest(unittest.TestCase):
         self.mod1.write(code)
         mover = move.create_move(self.project, self.mod1,
                                  code.index('a_method'))
-        self.assertEquals('def new_method(self, host):\n    return host.attr\n',
+        self.assertEquals('def new_method(self, host):'
+                          '\n    return host.attr\n',
                           mover.get_new_method('new_method'))
 
     def test_moving_methods_getting_new_method_renaming_main_object(self):
@@ -300,7 +307,8 @@ class MoveRefactoringTest(unittest.TestCase):
         self.mod1.write(code)
         mover = move.create_move(self.project, self.mod1,
                                  code.index('a_method'))
-        self.assertEquals('def new_method(self, host):\n    return host.attr\n',
+        self.assertEquals('def new_method(self, host):'
+                          '\n    return host.attr\n',
                           mover.get_new_method('new_method'))
 
     def test_moving_methods_gettin_new_method_with_keyword_arguments(self):
@@ -387,23 +395,23 @@ class MoveRefactoringTest(unittest.TestCase):
             '        return self.attr.new_method()\n',
             self.mod1.read())
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_moving_methods_and_nonexistent_attributes(self):
         code = 'class A(object):\n' \
                '    def a_method(self):\n        return 1\n'
         self.mod1.write(code)
-        mover = move.create_move(self.project, self.mod1,
-                                 code.index('a_method'))
-        mover.get_changes('x', 'new_method')
+        with self.assertRaises(exceptions.RefactoringError):
+            mover = move.create_move(self.project, self.mod1,
+                                     code.index('a_method'))
+            mover.get_changes('x', 'new_method')
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_unknown_attribute_type(self):
         code = 'class A(object):\n    attr = 1\n' \
                '    def a_method(self):\n        return 1\n'
         self.mod1.write(code)
-        mover = move.create_move(self.project, self.mod1,
-                                 code.index('a_method'))
-        mover.get_changes('attr', 'new_method')
+        with self.assertRaises(exceptions.RefactoringError):
+            mover = move.create_move(self.project, self.mod1,
+                                     code.index('a_method'))
+            mover.get_changes('attr', 'new_method')
 
     def test_moving_methods_and_moving_used_imports(self):
         self.mod2.write('class B(object):\n    var = 1\n')
@@ -497,10 +505,21 @@ class MoveRefactoringTest(unittest.TestCase):
         expected = 'import mod2\ns = """\\\n"""\nr = mod2.f()\n'
         self.assertEquals(expected, self.mod1.read())
 
-    @testutils.assert_raises(exceptions.RefactoringError)
     def test_raising_an_exception_when_moving_non_package_folders(self):
         dir = self.project.root.create_folder('dir')
-        mover = move.create_move(self.project, dir)
+        with self.assertRaises(exceptions.RefactoringError):
+            move.create_move(self.project, dir)
+
+    def test_moving_to_a_module_with_encoding_cookie(self):
+        code1 = '# -*- coding: utf-8 -*-'
+        self.mod1.write(code1)
+        code2 = 'def f(): pass\n'
+        self.mod2.write(code2)
+        mover = move.create_move(self.project, self.mod2,
+                                 code2.index('f()') + 1)
+        self.project.do(mover.get_changes(self.mod1))
+        expected = '%s\n%s' % (code1, code2)
+        self.assertEquals(expected, self.mod1.read())
 
 
 if __name__ == '__main__':
